define([
    'jquery',
    'js/utilities',
	'js/gesture',
	'js/sha256',
	'js/lib/md5.min',
	'js/validator',
    'hbs!containers/resetGesture/resetGesture',
], function(
	$$,
    utilities,
    gesturePlugin,
    SHA256,
    md5,
    validator,
    resetGestureTemplate
) {
	var $ = Framework7.$;
	var callAppApi = utilities.callAppApi;
	var gesturePassword = gesturePlugin.gesturePassword;
	var GestureView = gesturePlugin.GestureView;
	
	function render(params) {
		var loginStatus = JSON.parse(localStorage.getItem('loginStatus'));
		var gestureStatus = JSON.parse(localStorage.getItem('gestureStatus'));
		
		var gesturePromptList = [
 		    '请绘制手势密码图案，至少连接5个点',
 		    '请再次绘制手势密码图案',
 		    '正在设置中，请您耐心等待......',
 		    '请绘制原手势密码图案',
 		];
 		var gestureErrList = [
 		    '至少连接5个点，请重新绘制',
 		    '两次图案不一致，请重新绘制',
 		    '密码错误，还可绘制n次'
 		];
 		
		loadComponent('navbar', 'common', {
	    	container: '#resetGestureNavbar',
	    	title: '验证手势密码',
	    	backId: 'resetGestureBackBtn',
	    	isBackIcon: true,
	    	isBack: false,
	    	callback: function() {
	    		$('#resetGestureBackBtn').on('click', function() {
    				mainView.router.back({
    					url: 'setGestureMenu.html',
    					force: true,
    				});
	    		})
	    	}
	    });

		$('#resetGestureContent').html(resetGestureTemplate({
			
		}));
		
		$('#resetGestureOtherWayBtn').on('click', function() {
			verifyLoginPwd();
		});

		// 手势密码超过次数
		if (params.gestureValidCount == 0) {
            callAppApi({
                url: '/gesture/close/pwd',
                type: 'POST',
                params: {
                    userId: loginStatus.userId,
                },
                successCallback: function(res) {
                    if (res.closeResult == true) {
                        if (gestureStatus.userId == loginStatus.userId) {
                            gestureStatus.gesturePwd = false;
                            localStorage.setItem('gestureStatus', JSON.stringify(gestureStatus));
                        }

                        relogin();
                    } else if (res.closeResult == false) {
                        f7.alertMessage('关闭手势密码失败。');
                    }
                },
                errorCallback: function(err) {}
            });
		}
		
		// 登录密码验证超过次数
		if (params.loginValidCount == 0) {
			forbidLogin(params.validTime);
		}

		var resetGestureViewInstance = new GestureView('#resetGestureViewList');
		
		gesturePassword($$('#resetGestureArea'), {
			backgroundColor: 'transparent',
			color: '#f9ddcc',
			roundRadii: 36.5,
			pointRadii: 10,
			spaceHorizontal: 47,				// 圆圈之间的水平边距
			spaceVertical: 40,					// 圆圈之间的垂直边距
			paddingTop: 20,						// 上内边距
			paddingLeft: 30,					// 左内边距
			width: 375,
			height: 340,
			visibleLineStatus: false,
			lineColor: '#ff711e',
			rightColor: '#ff711e',
			wrongColor: 'red',
			zindex: 100,
			activePointCallback: function(activePointNum, pointList) {
				resetGestureViewInstance.update(pointList)
			},
			passwdWrongCallback: function() {
				// 清空手势密码图案展示
				resetGestureViewInstance.reset();
			},
		});
		
		$$('#resetGestureArea').on('hasPasswd', function(e, passwd) {
			var curPasswd = passwd.toString();
//			if (curPasswd.length < 5) {
//				// 更新提示信息
//				$('#resetGesturePrompt').text('');
//				// 更新错误信息
//				$('#resetGestureErr').text(gestureErrList[1])
//				// 清空手势密码图案展示
//				resetGestureViewInstance.reset();
//
//				// 触发错误事件
//				$$("#resetGestureArea").trigger("passwdWrong");
//			} else {
//				// 更新提示信息
//				$('#resetGesturePrompt').text(gesturePromptList[3]);
//				// 更新错误信息
//				$('#resetGestureErr').text('');

				callAppApi({
					url: '/gesture/verify/pwd',
					type: 'POST',
					params: {
						userId: loginStatus.userId,
						gesturePwd: SHA256(curPasswd).toString(),
						queryType: '1',				// '1' - 手势类型， '2' - 登录密码
						gestureType: '3',			// '1' - 登录， '2' - 关闭， '3' - 修改
					},
					successCallback: function(res) {
						if (res.verifyResult == true) {
							
							// 触发正确事件
							$$('#resetGestureArea').trigger('passwdRight');
							
							mainView.router.load({
								url: 'setGesture.html',
								query: {
									fromPage: 'resetGesture',
									resetGestureType: 'gesturePwd',
									gesturePwd: SHA256(curPasswd).toString(),
								}
							});
						} else if (res.verifyResult == false) {
							// 触发错误事件
							$$('#resetGestureArea').trigger('passwdWrong');
							
							if (res.validCount > 0) {
								var validCount = res.validCount.toString();
								
								// 更新错误信息
								$('#resetGestureErr').text(gestureErrList[2].replace(/n/, validCount));
							} else {
								$('#resetGestureErr').text('');

								callAppApi({
                                    url: '/gesture/close/pwd',
                                    type: 'POST',
                                    params: {
                                        userId: loginStatus.userId,
                                    },
                                    successCallback: function(res) {
                                        if (res.closeResult == true) {
                                            if (gestureStatus.userId == loginStatus.userId) {
                                                gestureStatus.gesturePwd = false;
                                                localStorage.setItem('gestureStatus', JSON.stringify(gestureStatus));
                                            }

                                            relogin();
                                        } else if (res.closeResult == false) {
                                            f7.alertMessage('关闭手势密码失败。');
                                        }
                                    },
                                    errorCallback: function(err) {}
								});
							}
						}
					},
					errorCallback: function(err) {
						// 触发错误事件
						$$("#resetGestureArea").trigger("passwdWrong");
						
						// 清空手势密码图案展示
						resetGestureViewInstance.reset();
					}
				})
				
//			}
		})
		
		function relogin() {
			f7.modal({
				title: '<span style="font-weight: normal; font-size: 16px;">手势密码已失效</span>',
				text: '<span style="color: #999">请重新登录</span>',
				buttons: [
				    {
				    	text: '<span style="color: #f4610b;">密码登录</span>',
				    	onClick: function() {
                            callAppApi({
                                url: '/app/logout',
                                type: 'POST',
                                params: {
                                    accountName : loginStatus.accountName,
                                    userSession: loginStatus.userSession
                                },
                                successCallback: function(logoutRes) {
                                    localStorage.setItem('loginStatus', JSON.stringify({
                                      userId: '',
                                      oldId: '',
                                      userSession: '',
                                      accountName: '',
                                      accountLoginType: '',
                                      orderList: [],
                                      oldUser: false
                                    }));

                                    localStorage.setItem('authStep1Data', '');
                                    localStorage.setItem('authStep2Data', '');

                                    f7.showToolbar('#toolbar');

                                    mainView.router.load({
                                        url: 'login.html',
                                        force: true,
                                        query: {
                                            targetPage: 'setting'
                                        }
                                    });
                                },
                                errorCallback: function(err) {}
                            })
				    	}
				    }
				]
			})
		}
		
		function verifyLoginPwd() {
    		var loginModal = f7.modal({
    			title: '<span style="font-weight: normal; font-size: 16px;">请输入登录密码</span>',
    			text: '<div style="position: relative; box-sizing: border-box; margin: 10px auto 0; border: 1px solid rgba(0, 0, 0, 0.2); width: 87.85%; height: 43px; overflow: hidden;">' +
    					'<input type="password" id="resetGestureLoginInput" style="box-sizing: border-box; border: none; padding-left: 5%; width: 100%; height: 42px; font-size: 14px;" />' + 
    					'<span class="hide" id="resetGestureLoginClearBtn" style="position: absolute; top: 0; right: 0; display: block; width: 40px; height: 42px; background-image: url(img/clear.png); background-repeat: no-repeat; background-position: center; background-size: 16px;"></span>' +
    				  '</div>' +
    				  '<p id="resetGestureErrorMsg" style="margin: 0 auto; width: 87.85%; min-height: 16px; text-align: left; line-height: 16px; color: #f41a1a; font-size: 10px;"></p>',
    			buttons: [
    			    {
    			    	text: '<span style="color: #999;">取消</span>',
    			    },
    			    {
    			    	text: '<span>确定</span>',
    			    	close: false,
    			    	onClick: function() {
    			    		var loginPwd = $('#resetGestureLoginInput').val();
    			    		var errMesEle = $('#resetGestureErrorMsg');

    			    		if (!loginPwd) { errMesEle.text('请输入密码'); errMesEle.css('margin', '4px auto 15px'); return false; }
    			    		if (!validator.checkPwd(loginPwd)) { errMesEle.text('密码必须是8位以上英文、数字组合'); errMesEle.css('margin', '4px auto 15px'); return false; }
    			    		
    			    		callAppApi({
    			    			url: '/gesture/verify/login',
    			    			type: 'POST',
    			    			params: {
    			    				userId: loginStatus.userId,
    			    				accountPwd: md5(loginPwd).toUpperCase(),
    			    				queryType: '2',				// '1' - 手势， '2' - 登录密码
    			    				gestureType: '3',			// '1' - 登录, '2' - 关闭, '3' - 修改
    			    			},
    			    			successCallback: function(res) {
    			    				if (res.verifyResult == true) {
    			    					f7.closeModal(loginModal);
    									mainView.router.load({
    										url: 'setGesture.html',
    										query: {
    											fromPage: 'resetGesture',
    											resetGestureType: 'loginPwd',
    											loginPwd: md5(loginPwd).toUpperCase(),
    										}
    									});
    			    				} else if (res.verifyResult == false) {
    			    					if (res.validCount > 0) {
    			    					    $('#resetGestureErrorMsg').css('margin', '4px auto 15px');
    			    						$('#resetGestureErrorMsg').text('登录密码错误，还可输入' + res.validCount.toString() + '次');
    			    					} else {
    			    						f7.closeModal(loginModal);
    			    						
    			    						forbidLogin(res.validTime);
    			    					}
    			    				}
    			    			},
    			    			errorCallback: function(err) {}
    			    		})
    			    	}
    			    }
    			]
    		});
    		
    		$(loginModal).on('opened', function(){
    			$('#resetGestureLoginInput').on('input', function(e) {
    				if ($(this).val() == '') {
    					$('#resetGestureLoginClearBtn').addClass('hide');
    				} else if ($(this).val() !== '') {
    					$('#resetGestureLoginClearBtn').removeClass('hide');
    				}
    			});
    			
    			$('#resetGestureLoginClearBtn').on('click', function() {
    				$('#resetGestureLoginInput').val('');
    				$(this).addClass('hide');
    			})
    		});
		}
		
		function forbidLogin(validTime) {
			f7.modal({
				text: '登录密码多次错误，请' + validTime + '后再试',
				buttons: [
				    {
				    	text: '确定',
				    	onClick: function() {
				    		mainView.router.back({
				    			url: 'setting.html',
				    			force: true,
				    			query: {
				    				fromPage: 'resetGesture',
				    			}
				    		});
				    	}
				    }
				]
			});
		}
		
	}
	
	return {
		render: render,
	}
});